@@ -4,8 +4,8 @@
 void Help::showHelp(const std::string_view& option) {
     if (option == "-v" || option == "--help") {
         std::cout << "libJSONHandle\n\n"
-                     "A library that makes a query in a JSON text.\n\n";
-        std::cout << "Version 1.1.0\n\n";
+                     "A library that makes a query or an edit in a JSON text.\n\n";
+        std::cout << "Version 1.2.0\n\n";
         std::cout << "The library is released under GNU Lesser General Public License version 3.0,\n"
                      "while the executable program is released under Apache License version 2.0.\n\n";
     }
@@ -14,9 +14,14 @@ void Help::showHelp(const std::string_view& option) {
         std::cout << "How to Use the Executable Program\n\n"
                      "jsonHandle [options]\n\n"
                      "For example:\n"
+                     "1. Make a query\n"
                      "jsonHandle example.json "
                      "-q candidates.content.parts.text "
-                     "-c candidates.content.role=model\n\n";
+                     "-c candidates.content.role=model\n"
+                     "2. Make an edit\n"
+                     "jsonHandle example.json "
+                     "-e \"hardware.gpu model=NVIDIA GeForce RTX 4060\" "
+                     "-c hardware.id=12345\n\n";
         std::cout << "Options:\n\n";
         std::cout << "<file>          The path of a JSON file.\n"
                      "                The file path should be enclosed in double quotation marks\n"
@@ -30,9 +35,17 @@ void Help::showHelp(const std::string_view& option) {
                      "For example:\n"
                      "-q candidates.content.parts.text\n"
                      "-q \"hardware.gpu brand\"\n\n"
+                     "-e              The assignment expression for an edit.\n"
+                     "                The hierarchy keys are separated by a dot.\n"
+                     "                There is an equals sign between the keys and the value.\n"
+                     "                If there is any space, the string with a space or the entire\n"
+                     "                string should be enclosed in double quotation marks.\n"
+                     "For example:\n"
+                     "-e \"hardware.cpu model\"=\"Intel Core i9 14900\"\n"
+                     "-e \"hardware.gpu model=NVIDIA GeForce RTX 4060\"\n\n"
                      "-c              The conditions for the query.\n"
-                     "                The hierarchy keys are separated by a dot,\n"
-                     "                The keys and the value are separated by an equal sign =.\n"
+                     "                The hierarchy keys are separated by a dot.\n"
+                     "                There is an equals sign between the keys and the value.\n"
                      "                Multiple conditions are separated by a comma.\n"
                      "                If there is any space, the string with a space or the entire\n"
                      "                string should be enclosed in double quotation marks.\n"
