@@ -2,7 +2,7 @@
 #define LIBJSONHANDLE_OPTIONS_H
 
 #include <expected>
-#include <filesystem>
+#include <string>
 
 
 class Options {
@@ -12,7 +12,7 @@ public:
      * std::string jsonText;
      * std::string query;
      */
-    static std::expected<std::array<std::string, 3>, std::string>
+    static std::expected<std::array<std::string, 4>, std::string>
     getOptions(int argc, char** argv);
 
 };
